aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlon Zakai <alonzakai@gmail.com>2014-01-23 17:58:46 -0800
committerAlon Zakai <alonzakai@gmail.com>2014-01-23 17:58:46 -0800
commit44998c302a9cd458d57802129c0cbc9d61dc10e7 (patch)
treee2ca0644dcd328787de5222a3e0428f50fe99d2d
parentc99a28dedf06cd1114f0b4f782b2e1e1d6c10051 (diff)
rename filePackageURL to filePackagePrefixURL
-rw-r--r--tests/test_browser.py6
-rw-r--r--tools/file_packager.py2
2 files changed, 4 insertions, 4 deletions
diff --git a/tools/file_packager.py b/tools/file_packager.py
index 6c60db58..9699730f 100644
--- a/tools/file_packager.py
+++ b/tools/file_packager.py
@@ -471,7 +471,7 @@ if has_preloaded:
PACKAGE_PATH = encodeURIComponent(location.pathname.toString().substring(0, location.pathname.toString().lastIndexOf('/')) + '/');
}
var PACKAGE_NAME = '%s';
- var REMOTE_PACKAGE_NAME = (Module['filePackageURL'] || '') + '%s';
+ var REMOTE_PACKAGE_NAME = (Module['filePackagePrefixURL'] || '') + '%s';
var PACKAGE_UUID = '%s';
''' % (data_target, remote_package_name, package_uuid)
diff --git a/tests/test_browser.py b/tests/test_browser.py
index 2c9407db..3000240d 100644
--- a/tests/test_browser.py
+++ b/tests/test_browser.py
@@ -588,7 +588,7 @@ If manually bisecting:
open(os.path.join(self.get_dir(), 'subdirr', 'data1.txt'), 'w').write('''1214141516171819''')
# change the file package base dir to look in a "cdn". note that normally you would add this in your own custom html file etc., and not by
# modifying the existing shell in this manner
- open(self.in_dir('shell.html'), 'w').write(open(path_from_root('src', 'shell.html')).read().replace('var Module = {', 'var Module = { filePackageURL: "cdn/", '))
+ open(self.in_dir('shell.html'), 'w').write(open(path_from_root('src', 'shell.html')).read().replace('var Module = {', 'var Module = { filePackagePrefixURL: "cdn/", '))
open(os.path.join(self.get_dir(), 'main.cpp'), 'w').write(self.with_report_result(r'''
#include <stdio.h>
#include <string.h>
@@ -615,8 +615,8 @@ If manually bisecting:
test()
# TODO: CORS, test using a full url for filePackageURL
#open(self.in_dir('shell.html'), 'w').write(open(path_from_root('src', 'shell.html')).read().replace('var Module = {', 'var Module = { filePackageURL: "http:/localhost:8888/cdn/", '))
#test()
def test_compressed_file(self):
@@ -615,8 +615,8 @@ If manually bisecting:
test()
- # TODO: CORS, test using a full url for filePackageURL
- #open(self.in_dir('shell.html'), 'w').write(open(path_from_root('src', 'shell.html')).read().replace('var Module = {', 'var Module = { filePackageURL: "http:/localhost:8888/cdn/", '))
+ # TODO: CORS, test using a full url for filePackagePrefixURL
+ #open(self.in_dir('shell.html'), 'w').write(open(path_from_root('src', 'shell.html')).read().replace('var Module = {', 'var Module = { filePackagePrefixURL: "http:/localhost:8888/cdn/", '))
#test()
def test_compressed_file(self):